Module plugin

Module plugin 

CLI channel plugin.

Factory for creating the CLI channel. Implements ChannelPlugin so the main binary can activate the CLI channel from configuration.

Note: The interactive readline loop is not started here — that is only used by the oxios chat subcommand.

Structs

CliPlugin
CLI channel plugin — creates a stdin/stdout channel.