pub struct CliChannelHandle {
pub incoming_tx: Sender<IncomingMessage>,
/* private fields */
}Expand description
Handle to the CLI channel, used to inject messages from the readline loop.
Fields
incoming_tx: Sender<IncomingMessage>Sender for injecting incoming messages into the gateway pipeline.
Implementations
Sourceimpl CliChannelHandle
impl CliChannelHandle
Sourcepub fn from_channel(channel: &CliChannel) -> Self
pub fn from_channel(channel: &CliChannel) -> Self
Creates a handle from a CliChannel.
Sourcepub async fn send_user_message(&self, content: String) -> Result<()>
pub async fn send_user_message(&self, content: String) -> Result<()>
Send a user message into the gateway pipeline.
Sourcepub fn touch_session(&self)
pub fn touch_session(&self)
Touch the session (update activity).
Sourcepub fn reset_session(&self)
pub fn reset_session(&self)
Reset the session (create a new one).
Sourcepub fn session_id(&self) -> Uuid
pub fn session_id(&self) -> Uuid
Get the current session ID.