Interactive readline loop using reedline.
Runs the main REPL: read user input, dispatch meta-commands, forward messages to the channel, and display responses.
Structs
- Interactive
Loop - The interactive read-eval-print loop.
Interactive readline loop using reedline.
Runs the main REPL: read user input, dispatch meta-commands, forward messages to the channel, and display responses.